fn empty_batch_response<R>(endpoint: SuotarEndpoint) -> SuotarBatchResponse<R>Expand description
Nothing to ask, so an empty batch is never sent and leaves no audit row.
fn empty_batch_response<R>(endpoint: SuotarEndpoint) -> SuotarBatchResponse<R>Nothing to ask, so an empty batch is never sent and leaves no audit row.