transport_variant

Function transport_variant 

fn transport_variant(error: &Error) -> SuotarErrorVariant
is_connect is the one case where the request provably never reached Suotar; everything else, a timeout above all, may have been processed.