pub struct ValidateCourseCodeRequestItem {
pub request_item_id: String,
pub course_code: String,
}Fields
request_item_id: Stringcourse_code: StringTrait Implementations
Sourceimpl Clone for ValidateCourseCodeRequestItem
impl Clone for ValidateCourseCodeRequestItem
Sourcefn clone(&self) -> ValidateCourseCodeRequestItem
fn clone(&self) -> ValidateCourseCodeRequestItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ValidateCourseCodeRequestItem
impl<'de> Deserialize<'de> for ValidateCourseCodeRequestItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ValidateCourseCodeRequestItem
impl PartialEq for ValidateCourseCodeRequestItem
Sourcefn eq(&self, other: &ValidateCourseCodeRequestItem) -> bool
fn eq(&self, other: &ValidateCourseCodeRequestItem) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SuotarRequestItem for ValidateCourseCodeRequestItem
impl SuotarRequestItem for ValidateCourseCodeRequestItem
fn request_item_id(&self) -> &str
Sourcefn student_number(&self) -> Option<&SecretString>
fn student_number(&self) -> Option<&SecretString>
The student number the item asks about, for the items that carry one.
impl Eq for ValidateCourseCodeRequestItem
impl StructuralPartialEq for ValidateCourseCodeRequestItem