fn transport_variant(error: &Error) -> SuotarErrorVariantExpand description
is_connect is the one case where the request provably never reached Suotar; everything else, a
timeout above all, may have been processed.
fn transport_variant(error: &Error) -> SuotarErrorVariantis_connect is the one case where the request provably never reached Suotar; everything else, a
timeout above all, may have been processed.